==> zio-aws-iam_3-5.17.121.2-sources.jar: zio/aws/iam/model/PolicyVersion.scala <==
package zio.aws.iam.model
import zio.aws.iam.model.primitives.{
  DateType,
  BooleanType,
  PolicyVersionIdType,
  PolicyDocumentType
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class PolicyVersion(
    document: Option[PolicyDocumentType] = None,
    versionId: Option[PolicyVersionIdType] = None,
    isDefaultVersion: Option[BooleanType] = None,
    createDate: Option[DateType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.PolicyVersion = {
    import PolicyVersion.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.PolicyVersion
      .builder()
      .optionallyWith(
        document.map(value =>
          PolicyDocumentType.unwrap(value): java.lang.String
        )
      )(_.document)
      .optionallyWith(
        versionId.map(value =>
          PolicyVersionIdType.unwrap(value): java.lang.String
        )
      )(_.versionId)
      .optionallyWith(
        isDefaultVersion.map(value =>
          BooleanType.unwrap(value): java.lang.Boolean
        )
      )(_.isDefaultVersion)
      .optionallyWith(createDate.map(value => DateType.unwrap(value): Instant))(
        _.createDate
      )
      .build()
  }
  def asReadOnly: zio.aws.iam.model.PolicyVersion.ReadOnly =
    zio.aws.iam.model.PolicyVersion.wrap(buildAwsValue())
}
object PolicyVersion {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.iam.model.PolicyVersion] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.PolicyVersion =
      zio.aws.iam.model.PolicyVersion(
        document.map(value => value),
        versionId.map(value => value),
        isDefaultVersion.map(value => value),
        createDate.map(value => value)
      )
    def document: Option[PolicyDocumentType]
    def versionId: Option[PolicyVersionIdType]
    def isDefaultVersion: Option[BooleanType]
    def createDate: Option[DateType]
    def getDocument: ZIO[Any, AwsError, PolicyDocumentType] =
      AwsError.unwrapOptionField("document", document)
    def getVersionId: ZIO[Any, AwsError, PolicyVersionIdType] =
      AwsError.unwrapOptionField("versionId", versionId)
    def getIsDefaultVersion: ZIO[Any, AwsError, BooleanType] =
      AwsError.unwrapOptionField("isDefaultVersion", isDefaultVersion)
    def getCreateDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("createDate", createDate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.PolicyVersion
  ) extends zio.aws.iam.model.PolicyVersion.ReadOnly {
    override val document: Option[PolicyDocumentType] = scala
      .Option(impl.document())
      .map(value => zio.aws.iam.model.primitives.PolicyDocumentType(value))
    override val versionId: Option[PolicyVersionIdType] = scala
      .Option(impl.versionId())
      .map(value => zio.aws.iam.model.primitives.PolicyVersionIdType(value))
    override val isDefaultVersion: Option[BooleanType] = scala
      .Option(impl.isDefaultVersion())
      .map(value => zio.aws.iam.model.primitives.BooleanType(value))
    override val createDate: Option[DateType] = scala
      .Option(impl.createDate())
      .map(value => zio.aws.iam.model.primitives.DateType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.PolicyVersion
  ): zio.aws.iam.model.PolicyVersion.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iam_3-5.17.201.1-sources.jar: zio/aws/iam/model/PolicyVersion.scala <==
package zio.aws.iam.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iam.model.primitives.{
  DateType,
  BooleanType,
  PolicyVersionIdType,
  PolicyDocumentType
}
import scala.jdk.CollectionConverters.*
final case class PolicyVersion(
    document: Optional[PolicyDocumentType] = Optional.Absent,
    versionId: Optional[PolicyVersionIdType] = Optional.Absent,
    isDefaultVersion: Optional[BooleanType] = Optional.Absent,
    createDate: Optional[DateType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.PolicyVersion = {
    import PolicyVersion.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.PolicyVersion
      .builder()
      .optionallyWith(
        document.map(value =>
          PolicyDocumentType.unwrap(value): java.lang.String
        )
      )(_.document)
      .optionallyWith(
        versionId.map(value =>
          PolicyVersionIdType.unwrap(value): java.lang.String
        )
      )(_.versionId)
      .optionallyWith(
        isDefaultVersion.map(value =>
          BooleanType.unwrap(value): java.lang.Boolean
        )
      )(_.isDefaultVersion)
      .optionallyWith(createDate.map(value => DateType.unwrap(value): Instant))(
        _.createDate
      )
      .build()
  }
  def asReadOnly: zio.aws.iam.model.PolicyVersion.ReadOnly =
    zio.aws.iam.model.PolicyVersion.wrap(buildAwsValue())
}
object PolicyVersion {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.iam.model.PolicyVersion] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.PolicyVersion =
      zio.aws.iam.model.PolicyVersion(
        document.map(value => value),
        versionId.map(value => value),
        isDefaultVersion.map(value => value),
        createDate.map(value => value)
      )
    def document: Optional[PolicyDocumentType]
    def versionId: Optional[PolicyVersionIdType]
    def isDefaultVersion: Optional[BooleanType]
    def createDate: Optional[DateType]
    def getDocument: ZIO[Any, AwsError, PolicyDocumentType] =
      AwsError.unwrapOptionField("document", document)
    def getVersionId: ZIO[Any, AwsError, PolicyVersionIdType] =
      AwsError.unwrapOptionField("versionId", versionId)
    def getIsDefaultVersion: ZIO[Any, AwsError, BooleanType] =
      AwsError.unwrapOptionField("isDefaultVersion", isDefaultVersion)
    def getCreateDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("createDate", createDate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.PolicyVersion
  ) extends zio.aws.iam.model.PolicyVersion.ReadOnly {
    override val document: Optional[PolicyDocumentType] = zio.aws.core.internal
      .optionalFromNullable(impl.document())
      .map(value => zio.aws.iam.model.primitives.PolicyDocumentType(value))
    override val versionId: Optional[PolicyVersionIdType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.versionId())
        .map(value => zio.aws.iam.model.primitives.PolicyVersionIdType(value))
    override val isDefaultVersion: Optional[BooleanType] = zio.aws.core.internal
      .optionalFromNullable(impl.isDefaultVersion())
      .map(value => zio.aws.iam.model.primitives.BooleanType(value))
    override val createDate: Optional[DateType] = zio.aws.core.internal
      .optionalFromNullable(impl.createDate())
      .map(value => zio.aws.iam.model.primitives.DateType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.PolicyVersion
  ): zio.aws.iam.model.PolicyVersion.ReadOnly = new Wrapper(impl)
}
